@@ -2,7 +2,7 @@ from unittest import TestCase
 
 from ossapi import RankingType, Cursor
 
-from tests import api
+from tests import api_v2 as api
 
 class TestCursor(TestCase):
     def test_nullable_cursor(self):
